==> puppet-module-puppetlabs-rsync_1.1.0.orig.tar.xz: puppet-module-puppetlabs-rsync-1.1.0/CHANGELOG.md <==
## Unsupported Release 1.1.0
### Summary

This minor release is a roll up of bug fixes and features.

#### Added
- migrate to `rspec-puppet-facts`.
- Add support for module `log file`.
- Added module options that are currently missing.

#### Fixed
- Change redirects during fixtures download.
- Add upper version boundary for `xinted` dependency.
- Replace legacy facts with new $facts hash.

## Unsupported Release 1.0.0
### Summary
This is a major release that drops Puppet 3 support.

#### Added
- `transfer_logging` and `log_format` parameters
- Now optional management of rsync install with new `manage_package` parameter
- Support for configuration via Hiera
- FreeBSD, RedHat family compatibility
- Make rsync::get compatible with `strict_variables` ([MODULES-3515](https://tickets.puppet.com/browse/MODULES-3515))
- `ignore_nonreadable` parameter
- Support for changing exclude/include order
- `chmod` and `logfile` parameters
- `.sync.yml` added for modulesync compatibility

#### Changed
- Bumps puppetlabs-stdlib dependency up to 4.2.0

#### Fixed
- Replace .to_a with Kernel#Array ([MODULES-1858](https://tickets.puppet.com/browse/MODULES-1858))


## 2015-01-20 - Release 0.4.0
### Summary

This release includes several new parameters and improvements.

#### Features
- Update `$include` and `$exclude` to support arrays
- Updated to use puppetlabs/concat instead of execs to build file!
- New parameters
  - rsync::get
    - `$options`
    - `$onlyif`
  - rsync::put
    - `$include`
    - `$options`
  - rsync::server::module
    - `$order`
    - `$refuse_options`

#### Bugfixes
- Fix auto-chmod of incoming and outgoing files when `incoming_chmod` or `outgoing_chmod` is set to false

## 2014-07-15 - Release 0.3.1
### Summary

This release merely updates metadata.json so the module can be uninstalled and
upgraded via the puppet module command.

## 2014-06-18 - Release 0.3.0
#### Features
- Added rsync::put defined type.
- Added `recursive`, `links`, `hardlinks`, `copylinks`, `times` and `include`
parameters to rsync::get.
- Added `uid` and `gid` parameters to rsync::server
- Improved support for Debian
- Added `exclude` parameter to rsync::server::module

#### Bugfixes
- Added /usr/local/bin to path for the rsync command exec.


## 2013-01-31 - Release 0.2.0
- Added use_chroot parameter.
- Ensure rsync package is installed.
- Compatibility changes for Ruby 2.0.
- Added execuser parameter to run command as specified user.
- Various typo and bug fixes.

## 2012-06-07 - Release 0.1.0
- Initial release

==> puppet-module-puppetlabs-rsync_1.2.0.orig.tar.xz: puppet-module-puppetlabs-rsync-1.2.0/CHANGELOG.md <==
## Unsupported Release 1.2.0
### Summary

This minor release is a roll up of bug fixes and features

#### Added
- Add support for CentOS8
- `pid_file` parameter to customize the pid file setting

#### Fixed
- rsync-daemon package is now automatically installed in CentOS8 when xinetd is disabled.

## Unsupported Release 1.1.1
### Summary

This minor release is to roll out a bug fix.

#### Fixed

- Duplicate line removed from template.
- Small documentation fix.

## Unsupported Release 1.1.0
### Summary

This minor release is a roll up of bug fixes and features.

#### Added
- migrate to `rspec-puppet-facts`.
- Add support for module `log file`.
- Added module options that are currently missing.

#### Fixed
- Change redirects during fixtures download.
- Add upper version boundary for `xinted` dependency.
- Replace legacy facts with new $facts hash.

## Unsupported Release 1.0.0
### Summary
This is a major release that drops Puppet 3 support.

#### Added
- `transfer_logging` and `log_format` parameters
- Now optional management of rsync install with new `manage_package` parameter
- Support for configuration via Hiera
- FreeBSD, RedHat family compatibility
- Make rsync::get compatible with `strict_variables` ([MODULES-3515](https://tickets.puppet.com/browse/MODULES-3515))
- `ignore_nonreadable` parameter
- Support for changing exclude/include order
- `chmod` and `logfile` parameters
- `.sync.yml` added for modulesync compatibility

#### Changed
- Bumps puppetlabs-stdlib dependency up to 4.2.0

#### Fixed
- Replace .to_a with Kernel#Array ([MODULES-1858](https://tickets.puppet.com/browse/MODULES-1858))


## 2015-01-20 - Release 0.4.0
### Summary

This release includes several new parameters and improvements.

#### Features
- Update `$include` and `$exclude` to support arrays
- Updated to use puppetlabs/concat instead of execs to build file!
- New parameters
  - rsync::get
    - `$options`
    - `$onlyif`
  - rsync::put
    - `$include`
    - `$options`
  - rsync::server::module
    - `$order`
    - `$refuse_options`

#### Bugfixes
- Fix auto-chmod of incoming and outgoing files when `incoming_chmod` or `outgoing_chmod` is set to false

## 2014-07-15 - Release 0.3.1
### Summary

This release merely updates metadata.json so the module can be uninstalled and
upgraded via the puppet module command.

## 2014-06-18 - Release 0.3.0
#### Features
- Added rsync::put defined type.
- Added `recursive`, `links`, `hardlinks`, `copylinks`, `times` and `include`
parameters to rsync::get.
- Added `uid` and `gid` parameters to rsync::server
- Improved support for Debian
- Added `exclude` parameter to rsync::server::module

#### Bugfixes
- Added /usr/local/bin to path for the rsync command exec.


## 2013-01-31 - Release 0.2.0
- Added use_chroot parameter.
- Ensure rsync package is installed.
- Compatibility changes for Ruby 2.0.
- Added execuser parameter to run command as specified user.
- Various typo and bug fixes.

## 2012-06-07 - Release 0.1.0
- Initial release
